@@ -1,4 +1,5 @@
 #![feature(proc_macro_hygiene, decl_macro)]
+use clap::{crate_name, crate_version};
 use log::*;
 use std::net::TcpListener;
 use std::sync::{Arc, Mutex};
@@ -7,9 +8,9 @@ mod args;
 mod janitor;
 mod peer_db;
 mod peer_handler;
-mod shared_state;
 #[cfg(feature = "server")]
 mod server;
+mod shared_state;
 
 #[cfg(test)]
 mod tests;
@@ -36,10 +37,10 @@ fn start_janitor(shared_state: &Arc<Mutex<SharedState>>, interval: u16, timeout:
   });
 }
 
-fn start_listener(shared_state: Arc<Mutex<SharedState>>, address: String, port: u16) {
-  let address = format!("{}:{}", address, port);
-  let listener = TcpListener::bind(&address).unwrap();
-  trace!("Listening on {}!", address);
+fn start_listener(shared_state: &Arc<Mutex<SharedState>>, address: String, port: u16) {
+  let address_with_port = format!("{}:{}", address, port);
+  info!("Starting listener on {}", address_with_port);
+  let listener = TcpListener::bind(&address_with_port).unwrap();
 
   for stream in listener.incoming() {
     if let Ok(stream) = stream {
@@ -53,6 +54,7 @@ fn start_listener(shared_state: Arc<Mutex<SharedState>>, address: String, port:
 fn main() {
   let args = args::get_arguments();
   pretty_env_logger::init_timed();
+  info!("Launched {} v{}", crate_name!(), crate_version!());
 
   let shared_state = SharedState::new();
   let shared_state = Arc::new(Mutex::new(shared_state));
@@ -60,5 +62,5 @@ fn main() {
   #[cfg(feature = "server")]
   start_server(&shared_state, args.rocket_port);
   start_janitor(&shared_state, args.interval, args.timeout);
-  start_listener(shared_state, args.address, args.port);
+  start_listener(&shared_state, args.address, args.port);
 }
